<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com
 */

/* Exclude category from blog */
if( ! function_exists( 'sewell_vt_excludeCat' ) ) {
  function sewell_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'sewell_vt_excludeCat');
}
/* Excerpt Length */
class SewellExcerpt {
  // Default length (by WordPress)
  public static $length = 55;

  // Output: sewell_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    SewellExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'SewellExcerpt::new_length');
    SewellExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(SewellExcerpt::$types[SewellExcerpt::$length]) )
      return SewellExcerpt::$types[SewellExcerpt::$length];
    else
      return SewellExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt
if( ! function_exists( 'sewell_excerpt' ) ) {
  function sewell_excerpt($length = 55) {
    SewellExcerpt::length($length);
  }
}

if ( ! function_exists( 'sewell_new_excerpt_more' ) ) {
  function sewell_new_excerpt_more( $more ) {
    return '[...]';
  }
  add_filter('excerpt_more', 'sewell_new_excerpt_more');
}
/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'sewell_vt_tag_cloud' ) ) {
  function sewell_vt_tag_cloud($tag_string) {
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'sewell_vt_tag_cloud', 10, 3);
}

/* Password Form */
function sewell_password_form() {
  // global $post;
  global $post;
  $password_title = cs_get_option('password_title');
  $password_title = ( $password_title ) ? $password_title : esc_html__( 'To continue it please enter your password below', 'sewell' );
  $password_button_text = cs_get_option('password_button_text');
  $password_button_text = ( $password_button_text ) ? $password_button_text : esc_html__('Access', 'sewell');
  $password_proof_bg = cs_get_option('password_proof_bg');
  $password_proof_bg = ( $password_proof_bg ) ? wp_get_attachment_url( $password_proof_bg )  :get_template_directory_uri().'/assets/images/backgrounds/bg6.png';

  $pass = '<div class="sewl-fullheight-wrap"><div class="sewl-static-bg" style="background-image:url('.$password_proof_bg.');"><div class="sewl-bg-wrap overlay"><div class="sewl-table-container"><div class="sewl-align-container"><div class="sewl-password-prodected"><i class="ti-lock"></i><span class="prodected-title">'.esc_attr( $password_title ).'</span><form action="'.esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ).'" method="post"><p><input name="post_password" type="password"/><input type="submit" value="'. esc_attr($password_button_text) .'" name="Submit"  /></p></form>';
  $pass .= '</div></div></div></div></div></div>';
  return $pass;
}
add_filter('the_password_form' , 'sewell_password_form');

/* Maintenance Mode */
if( ! function_exists( 'sewell_vt_maintenance_mode' ) ) {
  function sewell_vt_maintenance_mode() {
    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );
    $enable_maintenance_mode = cs_get_option( 'enable_maintenance_mode' );

    if ( isset($enable_maintenance_mode) && ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }
  }
  add_action( 'wp', 'sewell_vt_maintenance_mode', 1 );
}

/* Metas */
if ( ! function_exists( 'sewell_post_metas' ) ) {
  function sewell_post_metas() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  ?>
    <div class="blog-author">
    <?php
    if ( !in_array( 'author', $metas_hide ) ) { // Author Hide
      printf(
        '<strong class="post-author"><a href="%1$s" rel="author">%2$s</a></strong>',
        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        get_the_author()
      );
    }
    if ( !in_array( 'category', $metas_hide ) ) { // Category Hide
      if ( get_post_type() === 'post') { echo esc_html__( ' in ', 'sewell' );
        $category_list = get_the_category_list( ' ' );
        if ( $category_list ) {
          echo ' <span class="post-category">'. $category_list .'</span>';
        }
      }
    } // Category Hides
    if ( !in_array( 'date', $metas_hide ) ) { // Date Hide
    ?>
      <span class="post-date"><?php echo get_the_date('M d, Y'); ?></span>
    <?php } // Date Hides
     ?>
    </div>
  <?php
  }
}

/* Share Options */
if ( ! function_exists( 'sewell_wp_share_option' ) ) {
  function sewell_wp_share_option() {
    global $post;
    $page_url = get_permalink($post->ID );
    $thumb_id = get_post_thumbnail_id();
    $thumb_url_array = wp_get_attachment_image_src($thumb_id, 'full', true);
    $media_url = $thumb_url_array[0];
    $title = $post->post_title;
    $share_text = cs_get_option('share_text');
    $share_text = $share_text ? $share_text : esc_html__( 'Share', 'sewell' );
    $share_on_text = cs_get_option('share_on_text');
    $share_on_text = $share_on_text ? $share_on_text : esc_html__( 'Share On', 'sewell' );
    $hide_share_icons = (array) cs_get_option('hide_share_icons');
    ?>
    <div class="sewl-share">
    <p><?php echo esc_attr($share_text); ?></p>
    <ul>
      <?php if( !in_array('facebook', $hide_share_icons) ) { ?>
      <li>
        <a href="//www.facebook.com/sharer/sharer.php?u=<?php print(urlencode($page_url)); ?>&amp;t=<?php print(urlencode($title)); ?>" class="icon-fa-facebook" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_attr('Facebook', 'sewell'); ?>" target="_blank"><i class="fa fa-facebook-official"></i></a>
      </li>
      <?php }if( !in_array('twitter', $hide_share_icons) ) { ?>
      <li>
        <a href="//twitter.com/intent/tweet?text=<?php print(urlencode($title)); ?>&url=<?php print(urlencode($page_url)); ?>" class="icon-fa-twitter" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_attr('Twitter', 'sewell'); ?>" target="_blank"><i class="fa fa-twitter"></i></a>
      </li>
      <?php }if( !in_array('linkedin', $hide_share_icons) ) { ?>
      <li>
        <a href="//www.linkedin.com/shareArticle?mini=true&amp;url=<?php print(urlencode($page_url)); ?>&amp;title=<?php print(urlencode($title)); ?>" class="icon-fa-linkedin" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_attr('Linkedin', 'sewell'); ?>" target="_blank"><i class="fa fa-linkedin"></i></a>
      </li>
      <?php } if( !in_array('pinterest', $hide_share_icons) ) { ?>
      <li>
        <a href="//pinterest.com/pin/create/button/?url=<?php print(urlencode($page_url)); ?>&amp;description=<?php print(urlencode($title)); ?>&amp;media=<?php print(urlencode($media_url)); ?>" class="icon-fa-pinterest" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_attr('Pinterest', 'sewell'); ?>" target="_blank"><i class="fa fa-pinterest-p"></i></a>
      </li>
      <?php } ?>
    </ul>
  </div>
<?php
  }
}

// share rectangle
if ( ! function_exists( 'sewell_rectangle_share_option' ) ) {
  function sewell_rectangle_share_option() {
    global $post;
    $page_url = get_permalink($post->ID);
    $thumb_id = get_post_thumbnail_id();
    $thumb_url_array = wp_get_attachment_image_src($thumb_id, 'full', true);
    $media_url = $thumb_url_array[0];
    $title = $post->post_title;
    $share_text = cs_get_option('share_text');
    $share_text = $share_text ? $share_text : esc_html__( 'Share', 'sewell' );
    $share_on_text = cs_get_option('share_on_text');
    $share_on_text = $share_on_text ? $share_on_text : esc_html__( 'Share On', 'sewell' );
    $hide_share_icons = (array) cs_get_option('hide_share_icons');
    ?>
    <div class="sewl-rectangle-socials">
      <h6 class="social-label"><?php echo esc_attr($share_on_text); ?> <strong></strong></h6>
      <?php if( !in_array('facebook', $hide_share_icons) ) { ?>
      <a href="//www.facebook.com/share.php?u=<?php print(urlencode($page_url)); ?>&amp;t=<?php print(urlencode($title)); ?>" title="<?php echo esc_attr('Facebook', 'sewell'); ?>" target="_blank"><span class="sewl-table-container"><span class="sewl-align-container"><i class="fa fa-facebook"></i></span></span></a>
      <?php } if(!in_array('twitter', $hide_share_icons)) { ?>
      <a href="//twitter.com/intent/tweet?text=<?php print(urlencode($title)); ?>&url=<?php print(urlencode($page_url)); ?>" class="icon-fa-twitter" data-toggle="tooltip" data-placement="top" title="<?php  echo esc_attr('Twitter', 'sewell'); ?>" target="_blank"><span class="sewl-table-container"><span class="sewl-align-container"><i class="fa fa-twitter"></i></span></span></a>
      <?php } if(!in_array('linkedin', $hide_share_icons)) {  ?>
      <a href="//www.linkedin.com/shareArticle?mini=true&amp;url=<?php print(urlencode($page_url)); ?>&amp;title=<?php print(urlencode($title)); ?>" title="<?php echo esc_attr('Linkedin', 'sewell'); ?>" target="_blank"><span class="sewl-table-container"><span class="sewl-align-container"><i class="fa fa-linkedin"></i></span></span></a>
      <?php } if(!in_array('pinterest', $hide_share_icons)) {  ?>
      <a href="//pinterest.com/pin/create/button/?url=<?php print(urlencode($page_url)); ?>&amp;description=<?php print(urlencode($title)); ?>&amp;media=<?php print(urlencode($media_url)); ?>" title="<?php echo esc_attr('Pinterest', 'sewell'); ?>" target="_blank"><span class="sewl-table-container"><span class="sewl-align-container"><i class="fa fa-pinterest-p"></i></span></span></a>
      <?php } ?>
  </div>
<?php
  }
}

// posts tag
if(!function_exists( 'sewell_post_tags' )) {
  function sewell_post_tags() {
    $tag_list = get_the_tags();
    if($tag_list) { ?>
    <div class="sewl-tags">
      <?php echo the_tags( '<ul><li>', '</li><li>', '</li></ul>' ); ?>
    </div>
    <?php }
  }
}

/* Author Info */
if ( ! function_exists( 'sewell_author_info' ) ) {
  function sewell_author_info() {
    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
      $target = 'target="_blank"';
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $target = '';
    }
    // variables
    $author_content = get_the_author_meta( 'description' );
    $facebook = get_the_author_meta( 'facebook' );
    $twitter = get_the_author_meta( 'twitter' );
    $instagram = get_the_author_meta( 'instagram' );
    $pinterest = get_the_author_meta( 'pinterest' );
    if ($author_content) {
    ?>
    <div class="sewl-author-list">
      <div class="author-avatar">
        <a href="<?php echo esc_url($website_url); ?>" <?php echo esc_attr($target); ?>>
          <?php echo get_avatar( get_the_author_meta( 'ID' ), 101 ); ?>
        </a>
      </div>
      <div class="author-content">
        <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo get_the_author_meta('first_name').' '.get_the_author_meta('last_name'); ?></a>
        <p><?php echo get_the_author_meta( 'description' ); ?></p>
        <?php if( $facebook || $twitter || $instagram || $pinterest ) { ?>
        <div class="sewl-socials">
          <?php if($twitter) { ?>
            <a href="<?php echo esc_url( $twitter ); ?>"><i class="fa fa-twitter"></i></a>
          <?php } if($facebook) { ?>
            <a href="<?php echo esc_url( $facebook ); ?>"><i class="fa fa-facebook"></i></a>
          <?php } if($instagram) { ?>
            <a href="<?php echo esc_attr( $instagram ); ?>"><i class="fa fa-instagram"></i></a>
          <?php } if($pinterest) { ?>
            <a href="<?php echo esc_url( $pinterest ); ?>"><i class="fa fa-pinterest-p"></i></a>
          <?php } ?>
        </div>
        <?php } ?>
      </div>
    </div>
    <?php
    } // if $author_content

  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'sewell_comment_modification' ) ) {
  function sewell_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>
  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="">
    <?php endif; ?>
    <div class="comment-theme">
      <div class="comment-image">
        <?php if ( $args['avatar_size'] != 0 ) {
          echo get_avatar( $comment, 80 );
        } ?>
      </div>
    </div>
    <div class="comment-main-area">
      <div class="comment-wrapper">
        <div class="sewl-comments-meta">
        <h4><?php printf( '%s', get_comment_author() ); ?>
          <span class="comments-date"> says
            <?php echo get_comment_date('F d, Y'); ?> at
            <?php echo get_comment_time(); ?>
          </span></h4>
        </div>
        <div class="comment-area">
          <?php comment_text(); ?>
          <div class="comments-reply">
          <?php
            comment_reply_link( array_merge( $args, array(
            'reply_text' => '<span class="comment-reply-link">'. esc_html__('Reply','sewell') .'</span>',
            'before' => '',
            'class'  => '',
            'depth' => $depth,
            'max_depth' => $args['max_depth']
            ) ) );
          ?>
          </div>
        </div>
      </div>
      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'sewell' ); ?></em>
      <?php endif; ?>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Title Area */
if ( ! function_exists( 'sewell_title_area' ) ) {
  function sewell_title_area() {
    global $post, $wp_query;
    // Get post meta in all type of WP pages
    $sewell_id    = ( isset( $post ) ) ? $post->ID : 0;
    $sewell_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $sewell_id;
    $sewell_id    = ( is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $sewell_id;
    $sewell_meta  = get_post_meta( $sewell_id, 'page_type_metabox', true );
    if ($sewell_meta && (!is_archive() || is_woocommerce_shop())) {
      $custom_title = $sewell_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } elseif(post_type_archive_title()) {
        post_type_archive_title();
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    if ( is_home() ) {
      bloginfo('');
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'sewell' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ) {
      single_cat_title();
    } elseif ( is_tag() ) {
      single_tag_title(esc_html__('Posts Tagged: ', 'sewell'));
    } elseif ( is_archive() ) {
      if ( is_day() ) {
        printf( esc_html__( 'Archive for <span>%s</span>', 'sewell' ), get_the_date());
      } elseif ( is_month() ) {
        printf( esc_html__( 'Archive for <span>%s</span>', 'sewell' ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( esc_html__( 'Archive for <span>%s</span>', 'sewell' ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( esc_html__( 'Posts by: <span>%s</span>', 'sewell' ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( is_woocommerce_shop() ) {
        echo esc_attr($custom_title);
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        _e( 'Archives', 'sewell' );
      }
    } elseif( is_404() ) {
      _e('404 Error', 'sewell');
    } elseif( $custom_title ) {
      echo esc_attr($custom_title);
    } else {
      the_title();
    }

  }
}

/* WP Link Pages */
if ( ! function_exists( 'sewell_wp_link_pages' ) ) {
  function sewell_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'sewell' ).'</span>',
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

// pagination links
function sewell_paging_nav() {
  global $wp_query;
  $current = max( 1, absint( get_query_var( 'paged' ) ) );
  $pagination = paginate_links( array(
    'base' => str_replace( PHP_INT_MAX, '%#%', esc_url( get_pagenum_link( PHP_INT_MAX ) ) ),
    'format' => '?paged=%#%',
    'current' => $current,
    'total' => $wp_query->max_num_pages,
    'type' => 'array',
    'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>
          <span class="sr-only">Previous</span>',
    'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>
          <span class="sr-only">Next</span>',
  ) );

  echo "<pre>";
  var_dump($pagination);
  echo "</pre>";
   if ( ! empty( $pagination ) ) : ?>
    <nav class="items-navigation blog" aria-label="Page navigation">
        <ul class="pagination">
          <?php foreach ( $pagination as $key => $page_link ) : ?>
            <li class="paginated_link<?php if ( strpos( $page_link, 'current' ) !== false ) { echo ' active'; } ?>"><?php echo esc_url( $key ); ?></li>
          <?php endforeach ?>
        </ul>
    </nav>
<?php endif;
}
// apply_filters( 'sewell_bootstap_paginate_links', 'sewell_paging_nav' );

if ( ! function_exists( 'sewell_paginate_links' ) ) {
  function sewell_paginate_links() {
    global $wp_query;
    $big = 999999999;
    if($wp_query->max_num_pages > '1' ) {
      echo '<nav class="items-navigation blog" aria-label="Page navigation">';
    }
    echo paginate_links( array(
      'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
      'format' => '?paged=%#%',
      'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>
          <span class="sr-only">Previous</span>',
      'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>
          <span class="sr-only">Next</span>',
      'current' => max( 1, get_query_var('paged') ),
      'total' => $wp_query->max_num_pages,
      'type' => 'list'
    ));
    if($wp_query->max_num_pages > '1' ) {
      echo '</nav>';
    }
  }
}
// paging nav

if ( ! function_exists( 'sewell_custom_paginat_link' ) ) {
  function sewell_custom_paginat_link($numpages = '', $pagerange = '', $paged='') {
    if (empty($pagerange)) { $pagerange = 2; }
    if (empty($paged)) { $paged = 1; }
    if ($numpages == '') {
      global $wp_query;
      $numpages = $wp_query->max_num_pages;
      if(!$numpages) {
        $numpages = 1;
      }
    }
    $current = max( 1, absint( get_query_var( 'paged' ) ) );
    $big = 999999999;
    $paginations =  paginate_links( array(
      'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
      'format' => '?page=%#%',
      'current' => $current,
      'total' => $numpages,
      'type' => 'array',
      'prev_text' => '<i class="fa fa-angle-left" aria-hidden="true"></i>
              <span class="sr-only">Previous</span>',
      'next_text' => '<i class="fa fa-angle-right" aria-hidden="true"></i>
              <span class="sr-only">Next</span>',
      ));
  if ( ! empty( $paginations ) ) :
?>
  <nav class="items-navigation portfolio" aria-label="Page navigation">
    <ul class="pagination">
      <?php foreach ( $paginations as $key => $page_link ) : ?>
        <li class="paginated_link<?php if ( strpos( $page_link, 'current' ) !== false ) { echo ' active'; } ?>"><?php echo $page_link; ?></li>
      <?php endforeach ?>
    </ul>
  </nav>
      <?php
    endif;
  }
}

/**
 * SINGLE PAGINATION
 */
if(!function_exists('sewell_single_pagination')) {
  function sewell_single_pagination() {
  $next_post = get_next_post( '', false);
  $prev_post = get_previous_post( '', false);
  $newer_post = cs_get_option('newer_post');
  $newer_post = ( $newer_post ) ? $newer_post : esc_html__('Next Article', 'sewell');
  $older_post = cs_get_option('older_post');
  $older_post = ( $older_post ) ? $older_post : esc_html__('Previous Article', 'sewell');
  if (empty($next_post) || empty($prev_post)) {
    $style = 'border: none; width:100%;';
  } else {
    $style = '';
  }
?>
  <div class="sewl-more-posts">
    <?php if (!empty( $prev_post )): ?>
      <div class="previous-post" style="<?php echo esc_attr( $style ); ?>">
        <a href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>">
          <span class="post-control-link"><?php echo esc_attr($older_post); ?></span>
          <span class="post-name"><?php echo esc_attr($prev_post->post_title); ?></span>
        </a>
      </div>
      <?php endif;
      if (!empty( $next_post )): ?>
      <div class="next-post" style="<?php echo esc_attr( $style ); ?>">
        <a href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>">
          <span class="post-control-link"><?php echo esc_attr($newer_post); ?></span>
          <span class="post-name"><?php echo esc_attr($next_post->post_title); ?></span>
        </a>
      </div>
    <?php endif; ?>
  </div>
<?php
  }
}

/**
 * AJAX PAGINATION
 */
function sewell_ajax_infinite_load_more() {
$paged      = $_POST["page"]+1;
$inDate     = $_POST["inDate"];
$inMonth    = $_POST["inMonth"];
$inYear     = $_POST["inYear"];
$inTag      = $_POST["inTag"];
$inCategory = $_POST["inCategory"];
$inAuthor   = $_POST["inAuthor"];
$inSearch   = $_POST["inSearch"];
$posttype   = $_POST["inPostType"];
$order   = $_POST["inOrder"];
$orderby   = $_POST["inOrderBy"];
$limit   = $_POST["inLimit"];

$args = array(
  's'               =>  $inSearch,
  'year'            =>  (int) $inYear,
  'monthnum'        =>  (int) $inMonth,
  'day'             =>  (int) $inDate,
  'tag'             =>  $inTag,
  'author'          =>  $inAuthor,
  'category_name'   =>  $inCategory,
  'post_type'       => $posttype,
  'paged'           => $paged,
  'post_status'     => 'publish',
  'order'     => $order,
  'orderby'     => $orderby,
  'posts_per_page'     => (int) $orderby,
  );
  ob_start();
  $loop = new WP_Query( $args );
   $blog_style = $style;
  if( $loop->have_posts() ):
    while( $loop->have_posts() ): $loop->the_post();
        get_template_part( 'layouts/post/content', get_post_format() );
    endwhile;
    else:
      echo 0;
  endif; wp_reset_postdata();
  $data = ob_get_clean();
  wp_send_json_success( $data );
  wp_die();
}
add_action( 'wp_ajax_sewell_ajax_infinite_load_more', 'sewell_ajax_infinite_load_more' );
add_action( 'wp_ajax_nopriv_sewell_ajax_infinite_load_more', 'sewell_ajax_infinite_load_more' );

function sewell_ajax_infinite_hover_load() {
$paged      = $_POST["hpage"]+1;
$inDate     = $_POST["hDate"];
$inMonth    = $_POST["hMonth"];
$inYear     = $_POST["hYear"];
$inTag      = $_POST["hTag"];
$inCategory = $_POST["hCategory"];
$inAuthor   = $_POST["hAuthor"];
$inSearch   = $_POST["hSearch"];
$posttype   = $_POST["hPosttype"];
$order   = $_POST["hOrder"];
$orderby   = $_POST["hOrderBy"];
$limit   = $_POST["hLimit"];

$args = array(
  's'               =>  $inSearch,
  'year'            =>  (int) $inYear,
  'monthnum'        =>  (int) $inMonth,
  'day'             =>  (int) $inDate,
  'tag'             =>  $inTag,
  'author'          =>  $inAuthor,
  'category_name'   =>  $inCategory,
  'post_type'       => $posttype,
  'paged'           => $paged,
  'post_status'     => 'publish',
  'order'           => $order,
  'orderby'         => $orderby,
  'posts_per_page'  => (int) $limit,
  );
  ob_start();
  $loop = new WP_Query( $args );
   $blog_style = $style;
  if( $loop->have_posts() ):
    while( $loop->have_posts() ): $loop->the_post(); ?>
      <div id="post-<?php the_ID(); ?>" <?php post_class('blog-item'); ?>>
        <div class="blog-title"><a href="<?php echo esc_url( get_permalink() ); ?>" class="bp-heading"><?php echo esc_attr(get_the_title()); ?></a></div>
        <p>
          <?php
          $blog_excerpt = cs_get_option('theme_blog_excerpt');
          if ($blog_excerpt) {
            $blog_excerpt = $blog_excerpt;
          } else {
            $blog_excerpt = '30';
          }
          sewell_excerpt($blog_excerpt);
          echo sewell_wp_link_pages();
          ?>
        </p>
        <?php echo sewell_post_metas(); ?>
      </div>
    <?php
    endwhile;
  endif; wp_reset_postdata();
  $data = ob_get_clean();
  wp_send_json_success( $data );
  wp_die();
}
add_action( 'wp_ajax_sewell_ajax_infinite_hover_load', 'sewell_ajax_infinite_hover_load' );
add_action( 'wp_ajax_nopriv_sewell_ajax_infinite_hover_load', 'sewell_ajax_infinite_hover_load' );

// ajax button
function sewell_ajax_infinite_load_morebtn() {
$paged    = $_POST["pageb"]+1;
$search    = $_POST["search"];
$style2   = $_POST["style2"];
$style    = $_POST["style"];
$day      = $_POST["day"];
$month    = $_POST["month"];
$year     = $_POST["year"];
$tags     = $_POST["tags"];
$category = $_POST["category"];
$order = $_POST["order"];
$orderby = $_POST["orderby"];
$limit = $_POST["limit"];
$author   = $_POST["author"];
$posttype   = $_POST["postType"];
$args = array(
  'posts_per_page'            =>  (int) $limit,
  'order'            =>  $order,
  'orderby'            =>  $orderby,
  'year'            =>  (int) $year,
  'monthnum'        =>  (int) $month,
  'day'             =>  (int) $day,
  'tag'             =>  $tags,
  's'               =>  $search,
  'author'          =>  $author,
  'category_name'   =>  $category,
  'post_type'       => $posttype,
  'paged'           => $paged,
  'post_status'     => 'publish',
  );
  $loop = new WP_Query( $args );
  $blog_style = $style2;
  if( $loop->have_posts() ):
    while( $loop->have_posts() ): $loop->the_post();
      if ($blog_style == 'splitted') { ?>
        <div id="post-<?php the_ID(); ?>" <?php post_class('blog-item'); ?>>
            <div class="blog-title"><a href="<?php echo esc_url( get_permalink() ); ?>" class="bp-heading"><?php echo esc_attr(get_the_title()); ?></a></div>
            <p><?php
            $blog_excerpt = cs_get_option('theme_blog_excerpt');
            if ($blog_excerpt) {
              $blog_excerpt = $blog_excerpt;
            } else {
              $blog_excerpt = '30';
            }
            sewell_excerpt($blog_excerpt);
            echo sewell_wp_link_pages();
            ?></p>
            <?php echo sewell_post_metas();
            $pagination_type = cs_get_option('blog_pagination_type');
              if($pagination_type == 'navigation') {
              echo sewell_paginate_links();
            }
            wp_reset_postdata();  // avoid errors further down the page
            ?>
        </div>
      <?php
      } else {
        get_template_part( 'layouts/post/content', get_post_format() );
      }
    endwhile;
  endif;
  wp_reset_postdata();
  wp_die();
}
add_action( 'wp_ajax_sewell_ajax_infinite_load_morebtn', 'sewell_ajax_infinite_load_morebtn' );
add_action( 'wp_ajax_nopriv_sewell_ajax_infinite_load_morebtn', 'sewell_ajax_infinite_load_morebtn' );

if ( ! function_exists( 'sewell_ajax_pagination_btn' ) ) {
  function sewell_ajax_pagination_btn($message = 'There is no more stories', $blog_style ='', $posts = '', $order = '', $orderby = '', $limit ) {
    if (!empty($blog_style)) {
      $blog_style = $blog_style;
    }else{
      $blog_style = cs_get_option('blog_style');
    }

    if (!empty($order)) {
      $order = $order;
    }else{
      $order = '';
    }
    if (!empty($orderby)) {
      $orderby = $orderby;
    }else{
      $orderby = '';
    }
    if (!empty($limit)) {
      $limit = $limit;
    }else{
      $limit = '';
    }

global $wp_query;

if(is_archive()) {
  if (is_category()) {
      $category =  single_cat_title( '', false );
    } else {
      $category = '';
    }
    if (is_author()) {
      $author = get_the_author_meta( 'display_name', $wp_query->post->post_author );
    } else {
      $author = '';
    }
    if (is_tag()) {
      $tags = single_tag_title('', false);
    } else {
      $tags = '';
    }
    if (is_year()) {
      $year = get_the_date('Y');
    } else {
      if (is_month()) {
        $month = get_the_date('m');
        $year = get_the_date('Y');
      } else {
        if (is_day()) {
          $day = get_the_date('d');
          $month = get_the_date('m');
          $year = get_the_date('Y');
        } else {
          $day = '';
          $month = '';
          $year = '';
        }
        $day = '';
        $month = '';
        $year = '';
      }
      $day = '';
      $month = '';
      $year = '';
    }
} else {
   $tags = '';
   $author = '';
   $category = '';
   $year = '';
   $month = '';
   $day = '';
}
if (is_search()) {
  $search_term = (isset($_GET['searchterm'])) ? $_GET['searchterm'] : 0;
  $posttype = '';
} else {
  $search_term = '';
  $posttype = 'post';
}
if (!empty($posts)) {
  $posts = $posts;
}else{
  $posts = $wp_query->found_posts;
}
?>
  <div class="load_more_blog_messages"></div>
  <a class="load-more-posts load_more_btn" data-limit="<?php echo esc_attr(  $limit ); ?>" data-order="<?php echo esc_attr( $order ); ?>" data-orderby="<?php echo esc_attr( $orderby ); ?>" data-posttype="<?php echo esc_attr( $posttype ); ?>" data-search="<?php echo esc_attr( $search_term ); ?>" data-posts="<?php echo  esc_attr( $posts ); ?>" data-month="<?php echo esc_attr( $month ); ?>" data-tags="<?php echo esc_attr( $tags ); ?>" data-year="<?php echo esc_attr( $year ); ?>" data-day="<?php echo esc_attr( $day ); ?>" data-author="<?php echo esc_attr( $author ); ?>" data-category="<?php echo esc_attr( $category ); ?>" data-style="<?php echo esc_attr( $blog_style ); ?>" data-message="<?php echo esc_attr( $message ); ?>" data-pageb="1" data-url="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>"><img class="loader_gif" src="<?php echo get_template_directory_uri(); ?>/assets/images/icons/ajax-loader.gif" alt=""> <span class="icon_pagination"><i class="fa fa-refresh"></i></span> <span class="txt"><?php echo esc_html__( 'Load more' , 'sewell'); ?></span></a>
<?php
  }
}

if ( ! function_exists( 'sewell_infite_load_more' ) ) {
  function sewell_infite_load_more( $message = 'no more posts', $order = '', $orderby = '', $limit = '' ) {

    if (!empty($order)) {
      $order = $order;
    }else{
      $order = '';
    }
    if (!empty($orderby)) {
      $orderby = $orderby;
    }else{
      $orderby = '';
    }
    if (!empty($limit)) {
      $limit = $limit;
    }else{
      $limit = '';
    }

  global $wp_query;
  if(is_archive()) {
    if (is_category()) {
        $category =  single_cat_title( '', false );
      } else {
        $category = '';
      }
      if (is_author()) {
        $author = get_the_author_meta( 'display_name', $wp_query->post->post_author );
      } else {
        $author = '';
      }
      if (is_tag()) {
        $tags = single_tag_title('', false);
      } else {
        $tags = '';
      }
      if (is_year()) {
        $year = get_the_date('Y');
      } else {
        if (is_month()) {
          $month = get_the_date('m');
          $year = get_the_date('Y');
        } else {
          if (is_day()) {
            $day = get_the_date('d');
            $month = get_the_date('m');
            $year = get_the_date('Y');
          } else {
            $day = '';
            $month = '';
            $year = '';
          }
          $day = '';
          $month = '';
          $year = '';
        }
        $day = '';
        $month = '';
        $year = '';
      }
  } else {
     $tags = '';
     $author = '';
     $category = '';
     $year = '';
     $month = '';
     $day = '';
  }
  if (is_search()) {
    $search_term = (isset($_GET['searchterm'])) ? $_GET['searchterm'] : 0;
    $posttype = '';
  } else {
    $search_term = '';
    $posttype = 'post';
  }
  ?>
  <a data-message="<?php echo esc_attr( $message ); ?>" data-inlimit="<?php echo esc_attr( $limit ); ?>" data-inorderby="<?php echo esc_attr( $orderby ); ?>" data-inorder="<?php echo esc_attr( $order ); ?>" data-posttype="<?php echo esc_attr( $posttype ); ?>" data-insearch="<?php echo esc_attr( $search_term ); ?>"  data-posts="<?php echo  esc_attr( $wp_query->found_posts ); ?>" data-month="<?php echo esc_attr( $month ); ?>" data-tags="<?php echo esc_attr( $tags ); ?>" data-year="<?php echo esc_attr( $year ); ?>" data-day="<?php echo esc_attr( $day ); ?>" data-author="<?php echo esc_attr( $author ); ?>" data-category="<?php echo esc_attr( $category ); ?>" data-url="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>"  class="infiniteloadmore"><span class="loader"></span></a>
  <?php
  }
}

if ( ! function_exists( 'sewell_ajax_pagination_hover' ) ) {
  function sewell_ajax_pagination_hover( $message = 'no more posts', $order = '', $orderby = '', $limit = '', $total = '' ) {
    if (!empty($order)) {

  global $wp_query;
      $order = $order;
    }else{
      $order = '';
    }
    if (!empty($orderby)) {
      $orderby = $orderby;
    }else{
      $orderby = '';
    }
    if (!empty($limit)) {
      $limit = $limit;
    }else{
      $limit = '';
    }
if (!empty($total)) {
  $posts = $total;
}else{
  $posts = $wp_query->found_posts;
}
  if(is_archive()) {
    if (is_category()) {
        $category =  single_cat_title( '', false );
      } else {
        $category = '';
      }
      if (is_author()) {
        $author = get_the_author_meta( 'display_name', $wp_query->post->post_author );
      } else {
        $author = '';
      }
      if (is_tag()) {
        $tags = single_tag_title('', false);
      } else {
        $tags = '';
      }
      if (is_year()) {
        $year = get_the_date('Y');
      } else {
        if (is_month()) {
          $month = get_the_date('m');
          $year = get_the_date('Y');
        } else {
          if (is_day()) {
            $day = get_the_date('d');
            $month = get_the_date('m');
            $year = get_the_date('Y');
          } else {
            $day = '';
            $month = '';
            $year = '';
          }
          $day = '';
          $month = '';
          $year = '';
        }
        $day = '';
        $month = '';
        $year = '';
      }
  } else {
     $tags = '';
     $author = '';
     $category = '';
     $year = '';
     $month = '';
     $day = '';
  }
  if (is_search()) {
    $search_term = (isset($_GET['searchterm'])) ? $_GET['searchterm'] : 0;
    $posttype = '';
  } else {
    $search_term = '';
    $posttype = 'post';
  }
  ?>
  <a data-message="<?php echo esc_attr( $message ); ?>" data-inlimit="<?php echo esc_attr( $limit ); ?>" data-inorderby="<?php echo esc_attr( $orderby ); ?>" data-inorder="<?php echo esc_attr( $order ); ?>" data-posttype="<?php echo esc_attr( $posttype ); ?>" data-insearch="<?php echo esc_attr( $search_term ); ?>"  data-inposts="<?php echo  esc_attr( $posts ); ?>" data-month="<?php echo esc_attr( $month ); ?>" data-tags="<?php echo esc_attr( $tags ); ?>" data-year="<?php echo esc_attr( $year ); ?>" data-day="<?php echo esc_attr( $day ); ?>" data-author="<?php echo esc_attr( $author ); ?>" data-category="<?php echo esc_attr( $category ); ?>" data-url="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>"  class="load_more_hover"><span class="loader"></span></a>
  <?php
  }
}

// Ajax infinite scroll for portfolio
function sewell_portfolio_infinite_load_more() {
// looping
  $portPage = $_POST["portPage"]+1;
  $portfolio_limit = $_POST["portLimit"];
  $portfolio_show_category = $_POST["portCategory"];
  $portfolio_orderby = $_POST["portOrderBy"];
  $portfolio_order = $_POST["portOrder"];
  $portTag = $_POST["portTag"];
  $portAuthor = $_POST["portAuthor"];
  $portfolio_style = $_POST["portStyle"];
  $column_name = $_POST["portColumn"];
  $args = array(
      'tag'                 =>  $portTag,
      'paged'               => $portPage,
      'post_type'           => 'portfolio',
      'posts_per_page'      => (int)$portfolio_limit,
      'portfolio_category'  => esc_attr($portfolio_show_category),
      'orderby'             => esc_attr($portfolio_orderby),
      'order'               => esc_attr($portfolio_order),
  );
$sewl_port = new WP_Query( $args );
if ($sewl_port->have_posts()) : while ($sewl_port->have_posts()) : $sewl_port->the_post();
        $large_image =  wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'fullsize', false, '' );
        if ($large_image) {
            $featured_img = $large_image[0];
          } else {
              $featured_img = SEWELL_IMAGES.'/backgrounds/1000x850.jpg';
          }
        $portfolio_featurd_image = get_post_meta( get_the_ID(), 'portfolio_featurd_image', true );

        if ($portfolio_featurd_image) {
          if ( $portfolio_style == 'masonry' ) {
            if($portfolio_featurd_image['featured_image_masonry']) {
               $featured_img = wp_get_attachment_image_url( $portfolio_featurd_image['featured_image_masonry'], 'fullsize', true );
              } else {
                $featured_img = $featured_img;
              }
          } else {
            $featured_img = $featured_img;
          }
        } else {
          $featured_img = $featured_img;
        }
        // Category
        global $post;
        $terms = wp_get_post_terms(get_the_ID(),'portfolio_category');
        foreach ($terms as $term) {
            $cat_class = $term->slug .' ';
        }
        $count = count($terms);
        $i=0;
        $cat_class = '';
        if ($count > 0) {
          foreach ($terms as $term) {
            $i++;
              $cat_class .= $term->slug .' ';
            if ($count != $i) {
              $cat_class .= '';
            } else {
              $cat_class .= '';
            }
          }
        }
?>
  <div id="port-<?php the_ID(); ?>" class="<?php echo esc_attr( $column_name.' '.$cat_class ); ?>" data-category="<?php echo esc_attr( $cat_class ); ?>">
    <div class="masonry-wrap">
      <div class="clearfix"><img src="<?php echo esc_url( $featured_img ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"></div>
      <div class="gallery-info">
        <div class="sewl-table-container">
          <div class="sewl-align-container">
            <h3 class="gallery-title"><a href="<?php esc_url( the_permalink() ); ?>"><?php the_title(); ?></a></h3>
            <span class="gallery-category">
            <?php if( get_the_term_list( get_the_ID(), 'portfolio_category', '', ',', '' ) ) { ?>
            <div class="sewl-sub-heading">
              <?php
                $category_list = wp_get_post_terms(get_the_ID(), 'portfolio_category');
                $i=1;
                foreach ($category_list as $term) {
                  $term_link = get_term_link( $term );
                  echo '<span><a href="'. esc_url($term_link) .'">'. $term->name .'</a></span> ';
                  if($i++==2) break;
                }
              ?>
            </div>
         <?php } ?>
            </span>
          </div>
        </div>
      </div>
    </div>
  </div>
<?php
endwhile;
else:
echo 0;
endif;
  wp_reset_postdata();
  $data = ob_get_clean();
  wp_send_json_success( $data );
  wp_die();
}
add_action( 'wp_ajax_sewell_portfolio_infinite_load_more', 'sewell_portfolio_infinite_load_more' );
add_action( 'wp_ajax_nopriv_sewell_portfolio_infinite_load_more', 'sewell_portfolio_infinite_load_more' );

// button
function sewell_portfolio_load_morebtn() {
  // looping
  $paged = $_POST["pageb"]+1;
  $portfolio_limit = $_POST["portfolio_limit"];
  $portfolio_show_category = $_POST["portfolio_show_category"];
  $portfolio_orderby = $_POST["portfolio_orderby"];
  $portfolio_order = $_POST["portfolio_order"];
  $portfolio_style = $_POST["portfolio_style"];
  $column_name = $_POST["column_name"];
  $tags = $_POST["tags"];
  $author = $_POST["author"];
  $args = array(
        'tag' => $tags,
        'paged' => $paged,
        'post_type' => 'portfolio',
        'post_status' => 'publish',
        'posts_per_page' => (int)$portfolio_limit,
        'portfolio_category' => esc_attr($portfolio_show_category),
        'orderby' => esc_attr($portfolio_orderby),
        'order' => esc_attr($portfolio_order),
    );
$loop = new WP_Query( $args );
if( $loop->have_posts() ):
  while( $loop->have_posts() ): $loop->the_post();
    $large_image =  wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'fullsize', false, '' );
    $portfolio_featurd_image = get_post_meta( get_the_ID(), 'portfolio_featurd_image', true );

    if ($portfolio_featurd_image) {
      if($portfolio_style == 'grid') {
        if($portfolio_featurd_image['featured_image_grid']) {
          $featured_img = wp_get_attachment_image_url( $portfolio_featurd_image['featured_image_grid'], 'full', true);
        } else {
          $featured_img = $large_image[0];
        }
      } elseif ( $portfolio_style == 'masonry' ) {
        if($portfolio_featurd_image['featured_image_masonry']) {
           $featured_img = wp_get_attachment_image_url( $portfolio_featurd_image['featured_image_masonry'], 'fullsize', true );
          } else {
            $featured_img = $large_image[0];
          }
      } else {
        $featured_img = $large_image[0];
      }
    } else {
      $featured_img = $large_image[0];
    }
      global $post;
      $terms = wp_get_post_terms(get_the_ID(),'portfolio_category');
      foreach ($terms as $term) {
        $cat_class = $term->slug .' ';
      }
      $count = count($terms);
      $i=0;
      $cat_class = '';
      if ($count > 0) {
        foreach ($terms as $term) {
          $i++;
            $cat_class .= $term->slug .' ';
          if ($count != $i) {
            $cat_class .= '';
          } else {
            $cat_class .= '';
          }
        }
      } ?>
    <div id="port-<?php the_ID(); ?>" class="<?php echo esc_attr( $column_name.$cat_class ); ?>" data-category="<?php echo esc_attr( $cat_class ); ?>">
      <div class="masonry-wrap">
        <div class="clearfix"><img src="<?php echo esc_url( $featured_img ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"></div>
        <div class="gallery-info">
          <div class="sewl-table-container">
            <div class="sewl-align-container">
              <h3 class="gallery-title"><a href="<?php esc_url( the_permalink() ); ?>"><?php the_title(); ?></a></h3>
              <span class="gallery-category">
              <?php if( get_the_term_list( get_the_ID(), 'portfolio_category', '', ',', '' ) ) { ?>
              <div class="sewl-sub-heading">
                <?php
                  $category_list = wp_get_post_terms(get_the_ID(), 'portfolio_category');
                  $i=1;
                  foreach ($category_list as $term) {
                    $term_link = get_term_link( $term );
                    echo '<span><a href="'. esc_url($term_link) .'">'. $term->name .'</a></span> ';
                    if($i++==2) break;
                  }
                ?>
              </div>
           <?php } ?>
              </span>
            </div>
          </div>
        </div>
      </div>
    </div>
  <?php
      endwhile;
      else:
        echo 0;
    endif;
    wp_reset_postdata();
    wp_die();
}
add_action( 'wp_ajax_sewell_portfolio_load_morebtn', 'sewell_portfolio_load_morebtn' );
add_action( 'wp_ajax_nopriv_sewell_portfolio_load_morebtn', 'sewell_portfolio_load_morebtn' );

/**
 * First Term
 * Helper Function
 */
function ea_first_term( $taxonomy, $field ) {
  $terms = get_the_terms( get_the_ID(), $taxonomy );
  if( empty( $terms ) || is_wp_error( $terms ) )
    return false;
  // If there's only one term, use that
  if( 1 == count( $terms ) ) {
    $term = array_shift( $terms );
  } else {
    $term = array_shift( $list );
  }
    // Output
  if( $field && isset( $term->$field ) )
    return $term->$field;

  else
    return $term;
}
// audio video post formats
function sewell_embeded_audio( $type = array() ) {
  $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
  $embed =  get_media_embedded_in_content( $content, $type );
  if($embed) {
    $output = str_replace('?visual=true', '?visual=false', $embed[0] );
  } else {
    $output = '';
  }
  return $output;
}
// video post format
function sewell_embeded_video( $type = array() ) {
  $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
  $embed =  get_media_embedded_in_content( $content, $type );
 if($embed) {
  $output = str_replace('?visual=true', '?visual=false', $embed[0] );
  } else {
    $output = '';
  }
  return $output;
}

function sewell_testimonial_formating($content) {
if( get_post_type()=='testimonial' )
    return $content;
else
 return wpautop($content);
}
// testimonial formating
remove_filter('the_content','wpautop');
add_filter('the_content','sewell_testimonial_formating');

// information home
function sewell_home_information_meta( $meta_name, $meta_id ) {
    global $post;
    $info_metas  = get_post_meta( $post->ID, $meta_name, true );
    $informations = $info_metas[$meta_id];
    if ($informations) {
      $infos = $informations;
    } else {
      $infos = array();
    }
    if ( count($infos) > 0 ) {
      $cols = array_chunk($infos, ceil(count($infos)/2));
        foreach ($cols as $infos) {

        echo '<div class="col-md-6 col-sm-6">';
            foreach ( $infos as $key => $information ) {
              $meta_info = explode('<br>', nl2br($information['meta_info'], false));
              $meta_url = explode('<br>', nl2br($information['info_url'], false));
              if(!empty($information['info_url'])) {

                $meta_i = count($meta_info);
                $meta_u = count($meta_url);

                if ($meta_i > $meta_u) {
                  $meta_info = array_slice($meta_info, 0, count($meta_url));
                } elseif($meta_u > $meta_i) {
                  $meta_url = array_slice($meta_url, 0, count($meta_info));
                } else {
                  $meta_info = $meta_info;
                  $meta_url = $meta_url;
                }
                $totlal_info = array_combine($meta_info, $meta_url);
                ?>
                  <dl>
                    <dt><?php echo esc_attr($information['title']); ?></dt>
                    <dd>
                <?php foreach ($totlal_info as $info => $url) {  ?>
                          <span><a href="<?php echo trim($url);?>"><?php echo trim($info); ?></a></span>
                  <?php }  ?>
                    </dd>
                  </dl>
              <?php
              } else {
                   ?>
                  <dl>
                    <dt><?php echo esc_attr($information['title']); ?></dt>
                    <dd>
                <?php foreach ($meta_info as $key => $info) {  ?>
                          <span><?php echo trim($info); ?></span>
                  <?php }  ?>
                    </dd>
                  </dl>
                  <?php
              }

            }
        echo '</div>';
        }
    }
}

// information portfolio
function sewell_portfolio_information_meta( $meta_name, $meta_id ) {
    global $post;
    $portfolio_meta  = get_post_meta( $post->ID, $meta_name, true );
    $informations = $portfolio_meta[$meta_id];
    if ($informations) {
      $infos = $informations;
    } else {
      $infos = array();
    }
    foreach ( $infos as $key => $information ) {
      $meta_info = explode('<br>', nl2br($information['meta_info'], false));
      $meta_url = explode('<br>', nl2br($information['info_url'], false));

      if(!empty($information['info_url'])) {
        $meta_i = count($meta_info);
        $meta_u = count($meta_url);
        if ($meta_i > $meta_u) {
          $meta_info = array_slice($meta_info, 0, count($meta_url));
        } elseif($meta_u > $meta_i) {
          $meta_url = array_slice($meta_url, 0, count($meta_info));
        } else {
          $meta_info = $meta_info;
          $meta_url = $meta_url;
        }
        $totlal_info = array_combine($meta_info, $meta_url);
        ?>
          <dl>
            <dt><?php echo esc_attr($information['title']); ?></dt>
            <dd>
        <?php foreach ($totlal_info as $info => $url) {  ?>
                  <span><a href="<?php echo trim($url);?>"><?php echo trim($info); ?></a></span>
          <?php } ?>
            </dd>
          </dl>
      <?php
      } else {
           ?>
          <dl>
            <dt><?php echo esc_attr($information['title']); ?></dt>
            <dd>
        <?php foreach ($meta_info as $key => $info) { ?>
                  <span><?php echo trim($info); ?></span>
          <?php } ?>
            </dd>
          </dl>
          <?php
      }
    }
}

// single pagination portfolio
function sewell_portfolio_next_prev() {
  global $post;
    $sewell_prev_post = get_previous_post(false);
    $sewell_next_post = get_next_post(false);
    $p_home_url = cs_get_option('portfolio_home_url');
    ?>
    <div class="sewl-project-controls"><?php
    if ($sewell_prev_post) { ?><a href="<?php echo esc_url(get_permalink($sewell_prev_post->ID)); ?>"><i class="fa fa-angle-left" aria-hidden="true"></i></a><?php  } ?><a href="<?php echo esc_url( $p_home_url ); ?>" class="grid-controls"><span></span> <span></span> <span></span></a><?php  if ($sewell_next_post) { ?><a href="<?php echo esc_url(get_permalink($sewell_next_post->ID)); ?>"><i class="fa fa-angle-right" aria-hidden="true"></i></a><?php } ?></div>
<?php
}

/**
 * PRELOADER
 */
if(! function_exists( 'site_preloader' )) {
  function site_preloader() {
    $preloader_option  = cs_get_option('page_preloader');
    $upload_preloader  = cs_get_option('upload_preloader');
    $select_preloader  = cs_get_option('select_preloader');
    $preloader_background  = cs_get_option('preloader_background');
    $preloader_background = ( $preloader_background ) ? $preloader_background : '#22222';
    $select_preloader = ( $select_preloader ) ? $select_preloader : '';
    if( $preloader_option == true ) {
      if($upload_preloader) {
      $img_meta = wp_get_attachment_metadata($upload_preloader);
      $margin_left = $img_meta['width']/2;
      $margin_top = $img_meta['height']/2;
    } else {
      $margin_left = '';
      $margin_top ='';
    }
    ?>
    <div class="sewl-preloader" style="background-color:<?php echo esc_attr($preloader_background); ?>">
      <div class="loader-wrap">
       <?php if( $select_preloader == 'custom' ) { ?>
        <img src="<?php echo esc_url(wp_get_attachment_url($upload_preloader)) ; ?>" style="margin-left: -<?php echo esc_attr( $margin_left ); ?>px; margin-top: -<?php echo esc_attr( $margin_top ); ?>px; " >
        <?php } else {  ?>
          <!-- animated preloder start \-->
        <div class="loader">
          <div class="loader-inner <?php echo esc_attr( $select_preloader ); ?>"></div>
        </div>
      <?php
          }
        } ?>
      </div>
    </div><!--/ animated preloder end-->
<?php
  }
}

// scroll top button
function sewell_scroll_top_button() {
  $scroll_top_btn_height = cs_get_option('scroll_top_btn_height');
  $scroll_top_btn_width = cs_get_option('scroll_top_btn_width');
  $scroll_top_icon_size = cs_get_option('scroll_top_icon_size');
  $scroll_top_btn_color = cs_get_option('scroll_top_btn_color');
  $scroll_top_btn_bg = cs_get_option('scroll_top_btn_bg');
  $scroll_top_icon = cs_get_option('scroll_top_icon');
  $inline_style = '';
  if( $scroll_top_btn_height || $scroll_top_btn_width || $scroll_top_icon_size || $scroll_top_btn_color ||$scroll_top_btn_bg ) {
    $inline_style .= ( $scroll_top_btn_height ) ? 'height:'. sewell_core_check_px($scroll_top_btn_height) .';' : '';
    $inline_style .= ( $scroll_top_btn_width ) ? 'width:'. sewell_core_check_px($scroll_top_btn_width) .';' : '';
    $inline_style .= ( $scroll_top_icon_size ) ? 'font-size:'. sewell_core_check_px($scroll_top_icon_size) .';' : '';
    $inline_style .= ( $scroll_top_btn_color ) ? 'color:'. $scroll_top_btn_color .';' : '';
    $inline_style .= ( $scroll_top_btn_bg ) ? 'background:'. $scroll_top_btn_bg .';' : '';
  }
  $icon = ( $scroll_top_icon ) ? $scroll_top_icon : 'fa fa-angle-up';
  ?>
    <div class="sewl-back-top">
      <a href="#0" style="<?php echo esc_attr( $inline_style ); ?>"><i class="<?php echo esc_attr( $icon ); ?>" aria-hidden="true"></i></a>
    </div>
  <?php
}

/*
  SEWELL HEADER FUNCTION
*/
function sewell_header() {
  // Metabox
global $post;
$sewell_id    = ( isset( $post ) ) ? $post->ID : false;
$sewell_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $sewell_id;
$sewell_id    = ( is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $sewell_id;
$sewell_id    = ( ! is_tag() && ! is_archive() && ! is_search() && ! is_404() && ! is_singular('testimonial') ) ? $sewell_id : false;
$sewell_meta  = get_post_meta( $sewell_id, 'page_type_metabox', true );
$page_layout_options  = get_post_meta( $sewell_id, 'page_layout_options', true );
$portfolio_meta  = get_post_meta( $sewell_id, 'portfolio_single_metabox', true );
$sewell_c_gallery_metabox  = get_post_meta( $sewell_id, 'gallery_single_metabox', true );
// Header Style
if ($sewell_meta) {
  $sewell_header_design  = $sewell_meta['select_header_design'];
  $sewell_sticky_header  = $sewell_meta['sticky_header'];
} else {
  $sewell_header_design  = cs_get_option('select_header_design');
  $sewell_sticky_header  = cs_get_option('sticky_header');
}

if( $sewell_sticky_header == true ) {
  $sticky_class = ' active-sticky-header ';
} else {
  $sticky_class = '';
}

if ( $sewell_header_design === 'default' ) {
  $sewell_header_design_actual  = cs_get_option('select_header_design');
} else {
  $sewell_header_design_actual = ( $sewell_header_design ) ? $sewell_header_design : cs_get_option('select_header_design');
}
$blog_style = cs_get_option('blog_style');
// page wrap class
if($portfolio_meta){
  if ( is_single( 'portfolio' ) ) {
    if ( $portfolio_meta['portfolio_single_layout'] == 'portfolio_slider' || $portfolio_meta['portfolio_single_layout'] == 'portfolio_horizontal') {
      $port_wrap_class = ' sewl-primary-page ';
    }else{
      $port_wrap_class = '';
    }
  }else{
    $port_wrap_class = '';
  }
}else{
  $port_wrap_class = '';
}

if (is_page_template('about-me.php' ) || is_page_template('home-template.php' ) || ( is_single() && post_password_required() ) || is_404() || is_page_template('contact.php' ) ) {
  $w_class_name = 'sewl-primary-page';
} else {
    if($portfolio_meta) {
      if( is_singular( 'portfolio' ) && ($portfolio_meta['portfolio_single_layout'] == 'portfolio_slider') || ($portfolio_meta['portfolio_single_layout'] == 'portfolio_horizontal') ) {
        $w_class_name = 'sewl-primary-page';
      } else {
        $w_class_name = '';
      }
    } else {
      if ($sewell_c_gallery_metabox) {
        if ($sewell_c_gallery_metabox['gallery_layout'] == 'gallery_fullscreen' || $sewell_c_gallery_metabox['gallery_layout'] == 'gallery_kenburns' || $sewell_c_gallery_metabox['gallery_layout'] == 'gallery_horizontal' ) {

          $w_class_name = 'sewl-primary-page';
        } else {
          $w_class_name = '';
        }
      } else {
        if( is_home() || is_archive() ) {
          if ($blog_style == 'splitted') {
            $layout_class = 'blog-splitted';
            $w_class_name = 'sewl-primary-page';
          } else {
            $layout_class = 'blog-classic';
            $w_class_name = '';
          }
        } else {
          $w_class_name = '';
        }
      }
    }
  $layout_class = 'blog-classic';
}
  if($page_layout_options) {
    if($page_layout_options['page_layout'] == 'full-height') {
      $height_class = ' sewl-primary-page';
    } else {
      $height_class = '';
    }
  }else{
    $height_class = "";
  }
// wrapper class
if( is_404() ) {
  $style_404 = 'style="padding:0";';
} else {
  $style_404 = '';
}

// Preloader Active
$preloader_option  = cs_get_option('page_preloader');
if ( $preloader_option == true ) {
  $preloader_class = 'active-preloader ';
} else {
  $preloader_class = 'inactive-preloader ';
}
if ( !post_password_required()) {
  $password_class = '';
} else {
  $password_class = ' sewl-primary-page';
}
?>
<!-- sewl main wrap -->
  <div class="sewl-main-wrap <?php echo esc_attr( $sticky_class.$port_wrap_class.$preloader_class.$w_class_name.$height_class.$password_class ); ?>" <?php echo esc_attr( $style_404 ); ?>>
  <?php
    if ($sewell_header_design_actual === 'style_two') {
      get_template_part('layouts/header/header', 'two' );
    } else {
      get_template_part('layouts/header/header', 'one' );
    }
}

function sewell_video_format_data( $url ){
  $parsed = parse_url($url);
  if ( strpos( $parsed['host'], 'vimeo' ) !== false ) {
    $url = $url;
    preg_match(
        '/\/\/(www\.)?vimeo.com\/(\d+)($|\/)/',
        $url,
        $matches
    );
    $id = $matches[2];
    echo $id;
  } else {
    preg_match(
        '/[\\?\\&]v=([^\\?\\&]+)/',
        $url,
        $matches
      );
      $id = $matches[1];

    echo $id;
  }
}
