<?php
/*
 * All Theme Options for Sewell theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com
 */
function sewell_vt_settings( $settings ) {
  $settings           = array(
    'menu_title'      => SEWELL_NAME . esc_html__(' Options', 'sewell'),
    'menu_slug'       => sanitize_title(SEWELL_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => SEWELL_NAME .' <small>V-'. SEWELL_VERSION .' by <a href="'. SEWELL_BRAND_URL .'" target="_blank">'. SEWELL_BRAND_NAME .'</a></small>',
  );
  return $settings;
}
add_filter( 'cs_framework_settings', 'sewell_vt_settings' );

// Theme Framework Options
function sewell_vt_options( $options ) {

  $options      = array(); // remove old options
  // ------------------------------
  // Theme Brand
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_brand',
    'title'    => esc_html__('Brand', 'sewell'),
    'icon'     => 'fa fa-bookmark',
    'sections' => array(
      // brand logo tab
      array(
        'name'     => 'brand_logo_title',
        'title'    => esc_html__('Logo', 'sewell'),
        'icon'     => 'fa fa-star',
        'fields'   => array(
          // Site Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Site Logo', 'sewell')
          ),
          array(
            'id'    => 'brand_logo_default',
            'type'  => 'image',
            'title' => esc_html__('Default Logo', 'sewell'),
            'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'sewell'),
            'add_title' => esc_html__('Add Logo', 'sewell'),
          ),
          array(
            'id'    => 'brand_logo_retina',
            'type'  => 'image',
            'title' => esc_html__('Retina Logo', 'sewell'),
            'info'  => esc_html__('Upload your retina logo here. Recommended size is 2x from default logo.', 'sewell'),
            'add_title' => esc_html__('Add Retina Logo', 'sewell'),
          ),
          array(
            'id'          => 'retina_width',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Width', 'sewell'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'retina_height',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Height', 'sewell'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_top',
            'type'        => 'number',
            'title'       => esc_html__('Logo Top Space', 'sewell'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_bottom',
            'type'        => 'number',
            'title'       => esc_html__('Logo Bottom Space', 'sewell'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),

         // WordPress Admin Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('WordPress Admin Logo', 'sewell')
          ),
          array(
            'id'    => 'brand_logo_wp',
            'type'  => 'image',
            'title' => esc_html__('Login logo', 'sewell'),
            'info'  => esc_html__('Upload your WordPress login page logo here.', 'sewell'),
            'add_title' => esc_html__('Add Login Logo', 'sewell'),
          ),
        ) // end: fields
      ), // end: section

      // Fav
      array(
        'name'     => 'brand_fav',
        'title'    => esc_html__('Fav Icon', 'sewell'),
        'icon'     => 'fa fa-anchor',
        'fields'   => array(

            // -----------------------------
            // Begin: Fav
            // -----------------------------
            array(
              'id'    => 'brand_fav_icon',
              'type'  => 'image',
              'title' => esc_html__('Fav Icon', 'sewell'),
              'info'  => esc_html__('Upload your site fav icon, size should be 16x16.', 'sewell'),
              'add_title' => esc_html__('Add Fav Icon', 'sewell'),
            ),
            array(
              'id'    => 'iphone_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone icon', 'sewell'),
              'info'  => esc_html__('Icon for Apple iPhone (57px x 57px). This icon is used for Bookmark on Home screen.', 'sewell'),
              'add_title' => esc_html__('Add iPhone Icon', 'sewell'),
            ),
            array(
              'id'    => 'iphone_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone retina icon', 'sewell'),
              'info'  => esc_html__('Icon for Apple iPhone retina (114px x114px). This icon is used for Bookmark on Home screen.', 'sewell'),
              'add_title' => esc_html__('Add iPhone Retina Icon', 'sewell'),
            ),
            array(
              'id'    => 'ipad_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad icon', 'sewell'),
              'info'  => esc_html__('Icon for Apple iPad (72px x 72px). This icon is used for Bookmark on Home screen.', 'sewell'),
              'add_title' => esc_html__('Add iPad Icon', 'sewell'),
            ),
            array(
              'id'    => 'ipad_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad retina icon', 'sewell'),
              'info'  => esc_html__('Icon for Apple iPad retina (144px x 144px). This icon is used for Bookmark on Home screen.', 'sewell'),
              'add_title' => esc_html__('Add iPad Retina Icon', 'sewell'),
            ),

        ) // end: fields
      ), // end: section

    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'sewell'),
    'icon'   => 'fa fa-file-text'
  );
  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'sewell'),
    'icon'        => 'fa fa-wrench',
    // begin: fields
    'fields'      => array(
      // -----------------------------
      // Begin: Responsive
      // -----------------------------
      array(
        'id'    => 'theme_responsive',
        'type'  => 'switcher',
        'title' => esc_html__('Responsive', 'sewell'),
        'info' => esc_html__('Turn off if you don\'t want your site to be responsive.', 'sewell'),
        'default' => true,
      ),
      array(
        'id'    => 'theme_page_comments',
        'type'  => 'switcher',
        'title' => esc_html__('Page Comments', 'sewell'),
        'info' => esc_html__('Turn On if you want to show comments in your pages.', 'sewell'),
        'default' => true,
      ),
      array(
        'id'    => 'page_preloader',
        'type'  => 'switcher',
        'title' => esc_html__('Preloader', 'sewell'),
        'info'  => esc_html__('Turn On if you want to run preloader.', 'sewell'),
        'default' => false,
      ),
      array(
        'id'      => 'select_preloader',
        'type'    => 'select',
        'title'   => esc_html__('Select Preloader', 'sewell'),
        'options'    => array(
          'default'                     => esc_html__('Select Preloader Spin', 'sewell'),
          'square-spin'                 => esc_html__('Square Spin', 'sewell'),
          'cube-transition'             => esc_html__('Cube Transition', 'sewell'),
          'ball-pulse'                  => esc_html__('Ball Pulse', 'sewell'),
          'ball-pulse-sync'             => esc_html__('Ball Pulse Sync', 'sewell'),
          'ball-grid-pulse'             => esc_html__('Ball Grid Pulse', 'sewell'),
          'ball-clip-rotate'            => esc_html__('Ball Clip Rotate', 'sewell'),
          'ball-clip-rotate-pulse'      => esc_html__('Ball Clip Rotate Pulse', 'sewell'),
          'ball-clip-rotate-multiple'   => esc_html__('Ball Clip Rotate Multiple', 'sewell'),
          'ball-pulse-rise'             => esc_html__('Ball Pulse Rise', 'sewell'),
          'ball-rotate'                 => esc_html__('Ball Rotate', 'sewell'),
          'ball-zig-zag'                => esc_html__('Ball Zig-Zag', 'sewell'),
          'ball-zig-zag-deflect'        => esc_html__('Ball Zig-Zag Deflect', 'sewell'),
          'ball-triangle-path'          => esc_html__('ball-triangle-path', 'sewell'),
          'ball-scale'                  => esc_html__('Ball Scale', 'sewell'),
          'ball-scale-multiple'         => esc_html__('Ball Scale Multiple', 'sewell'),
          'ball-scale-ripple'           => esc_html__('Ball Scale Ripple', 'sewell'),
          'ball-beat'                   => esc_html__('Ball Beat', 'sewell'),
          'ball-scale-ripple-multiple'  => esc_html__('Ball Scale Ripple Multiple', 'sewell'),
          'ball-spin-fade-loader'       => esc_html__('Ball Spin Fade Loader', 'sewell'),
          'ball-grid-beat'              => esc_html__('Ball Grid Beat', 'sewell'),
          'line-scale'                  => esc_html__('Line Scale', 'sewell'),
          'line-scale-party'            => esc_html__('Line Scale Party', 'sewell'),
          'line-scale-pulse-out'        => esc_html__('Line Scale Pulse Out', 'sewell'),
          'line-scale-pulse-out-rapid'  => esc_html__('Line Scale Pulse Out Rapid', 'sewell'),
          'line-spin-fade-loader'       => esc_html__('Line Spin Fade Loader', 'sewell'),
          'triangle-skew-spin'          => esc_html__('Triangle Skew Spin', 'sewell'),
          'pacman'                      => esc_html__('Pacman', 'sewell'),
          'semi-circle-spin'            => esc_html__('Semi Circle Spin', 'sewell'),
          'custom'                      => esc_html__('Custom', 'sewell'),
        ),
        'dependency'   => array( 'page_preloader', '==', 'true' ),
        'default'   => 'default',
      ),
      array(
        'id'    => 'preloader_background',
        'type'  => 'color_picker',
        'default'  => '#222222',
        'title' => esc_html__('Preloader Background', 'sewell'),
        'info' => esc_html__('Select your prelloader background color.', 'sewell'),
        'dependency'   => array( 'select_preloader|page_preloader', '!=|==', 'custom|true' ),
      ),
      array(
        'id'    => 'upload_preloader',
        'type'  => 'image',
        'title' => esc_html__('Upload Preloader', 'sewell'),
        'info' => esc_html__('Upload if you want to show custom Preloader in your pages.', 'sewell'),
        'dependency'   => array( 'select_preloader', '==', 'custom' ),
      ),
      array(
        'id'    => 'scroll_top_btn',
        'type'  => 'switcher',
        'title' => esc_html__('Scroll Top Button', 'sewell'),
        'info' => esc_html__('Turn On if you want to show Preloader in your pages.', 'sewell'),
        'default' => true,
      ),
      array(
        'id'          => 'scroll_top_btn_height',
        'type'        => 'number',
        'title'       => esc_html__('Button Height', 'sewell'),
        'unit'        => 'px',
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'          => 'scroll_top_btn_width',
        'type'        => 'number',
        'title'       => esc_html__('Bottom Width', 'sewell'),
        'unit'        => 'px',
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'          => 'scroll_top_icon_size',
        'type'        => 'number',
        'title'       => esc_html__('Icon Font Size', 'sewell'),
        'unit'        => 'px',
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'      => 'scroll_top_btn_color',
        'type'    => 'color_picker',
        'title'   => esc_html__('Button Color', 'sewell'),
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'      => 'scroll_top_btn_bg',
        'type'    => 'color_picker',
        'title'   => esc_html__('Button Background', 'sewell'),
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'      => 'scroll_top_icon',
        'type'    => 'icon',
        'title'   => esc_html__('Button Icon', 'sewell'),
        'dependency' => array( 'scroll_top_btn', '==', 'true' ),
      ),
      array(
        'id'      => 'popup_background',
        'type'    => 'select',
        'title'   => esc_html__('Theme Popup Option', 'sewell'),
        'class'      => 'vertical',
        'options'    => array(
          'dark'   => esc_html__('Dark Popup', 'sewell'),
          'light'   => esc_html__('Light Popup', 'sewell'),
        ),
      ),
      array(
        'id'      => 'hide_share_icons',
        'type'    => 'checkbox',
        'title'   => esc_html__('Hide Share Icon', 'sewell'),
        'class'      => 'vertical',
        'options'    => array(
          'facebook'   => esc_html__('Facebook', 'sewell'),
          'twitter'   => esc_html__('Twitter', 'sewell'),
          'linkedin'   => esc_html__('Linkedin', 'sewell'),
          'pinterest'   => esc_html__('Pinterest', 'sewell'),
          'googlel_plus'   => esc_html__('Google Plus', 'sewell'),
        ),
      ),
      array(
        'id'      => 'hide_image_options',
        'type'    => 'checkbox',
        'title'   => esc_html__('Hide Image Options', 'sewell'),
        'class'      => 'vertical',
        'options'    => array(
          'actual_size'   => esc_html__('Actual Size', 'sewell'),
          'zoom_out'   => esc_html__('Zoom Out', 'sewell'),
          'zoom_in'   => esc_html__('Zoom In', 'sewell'),
          'share'   => esc_html__('Share', 'sewell'),
          'fullscreen'   => esc_html__('Fullscreen', 'sewell'),
          'autoplay'   => esc_html__('Autoplay', 'sewell'),
          'download'   => esc_html__('Download', 'sewell'),
        ),
      ),
    ), // end: fields
  );
  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'sewell'),
    'icon'     => 'fa fa-bars',
    'sections' => array(
      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'sewell'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(
          // Header Select
          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'sewell'),
            'options'      => array(
              'default'    => SEWELL_CS_IMAGES .'/hs-1.jpg',
              'style_two'    => SEWELL_CS_IMAGES .'/hs-3.jpg',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'        => true,
            'default'   => 'default',
            'info' => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'sewell'),
          ),
          // Header Select
          // Extra's
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Extra\'s', 'sewell'),
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'sewell'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'sewell'),
            'default' => true,
          ),
        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'sewell'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(
          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Title Area', 'sewell')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar', 'sewell'),
            'label'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'sewell'),
            'default'    => true,
          ),
          array(
            'id'             => 'title_bar_height',
            'type'           => 'select',
            'title'          => esc_html__('Titlle area height', 'sewell'),
            'options'        => array(
              'default' => esc_html__('Default Height', 'sewell'),
              'height-custom' => esc_html__('Custom Height', 'sewell'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'title_bar_custom_height',
            'type'           => 'text',
            'title'          => esc_html__('Titlle area height', 'sewell'),
            'options'        => array(
              'default' => esc_html__('Default Height', 'sewell'),
              'height-custom' => esc_html__('Custom Height', 'sewell'),
            ),
            'dependency'   => array( 'title_bar_height', '==', 'height-custom' ),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Background Options', 'sewell'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg',
            'type'    => 'background',
            'title'   => esc_html__('Background', 'sewell'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
        )
      ),
    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'sewell'),
    'icon'     => 'fa fa-ellipsis-h',
    'fields' => array(
      // Copyright
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Footer Layout', 'sewell'),
      ),
      array(
        'id'    => 'need_footer_left',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Footer Left Section', 'sewell'),
        'default' => true,
      ),
      array(
        'id'    => 'footer_left_shortcode',
        'type'  => 'textarea',
        'title' => esc_html__('Footer Left', 'sewell'),
        'shortcode' => true,
        'dependency' => array('need_footer_left', '==', true),
        'after'       => 'Helpful shortcodes: [vt_footer_menus] [vt_socials] or any shortcode.',
      ),
      array(
        'id'    => 'need_footer_right',
        'type'  => 'switcher',
        'title' => esc_html__('Enable Footer Right Section', 'sewell'),
        'default' => true,
      ),
      array(
        'id'    => 'footer_right_shortcode',
        'type'  => 'textarea',
        'title' => esc_html__('Footer Right', 'sewell'),
        'shortcode' => true,
        'dependency' => array('need_footer_right', '==', true),
        'after'       => 'Helpful shortcodes: [vt_footer_menus] [vt_socials]  or any shortcode.',
      ),
    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'sewell'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'sewell'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'sewell'),
      ),
      array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => __('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer.
          <br /><br />Highly customizable colors are in <strong>Appearance > Customize</strong>', 'sewell'),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'sewell'),
    'icon'     => 'fa fa-header',
    'fields' => array(
      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'sewell'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'sewell'),
            'info'           => __('Enter css selectors like : <strong>body, .custom-class</strong>', 'sewell'),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'sewell'),
          ),
          array(
            'id'              => 'size',
            'type'            => 'text',
            'title'           => esc_html__('Font Size', 'sewell'),
          ),
          array(
            'id'              => 'line_height',
            'type'            => 'text',
            'title'           => esc_html__('Line-Height', 'sewell'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'sewell'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'sewell'),
        'accordion_title'     => esc_html__('New Typography', 'sewell'),
        'default'             => array(
          array(
            'title'           => esc_html__('Body Typography', 'sewell'),
            'selector'        => 'body, .sewl-detail-page',
            'font'            => array(
              'family'        => 'Rajdhani',
              'variant'       => 'regular',
            ),
            'size'            => '14px',
            'line_height'     => '1.42857143',
          ),
          array(
            'title'           => esc_html__('Menu Typography', 'sewell'),
            'selector'        => '.sewl-header .navbar-nav > li > a',
            'font'            => array(
              'family'        => 'Rajdhani',
              'variant'       => 'regular',
            ),
            'size'            => '14px',
          ),
          array(
            'title'           => esc_html__('Sub Menu Typography', 'sewell'),
            'selector'        => '.dropdown-menu > li > a',
            'font'            => array(
              'family'        => 'Rajdhani',
              'variant'       => 'regular',
            ),
            'size'            => '14px',
            'line_height'     => '1.42857143',
          ),
          array(
            'title'           => esc_html__('Headings Typography', 'sewell'),
            'selector'        => 'h1, h2, h3, h4, h5, h6, div.entry-content h1, div.entry-content h2, div.entry-content h3, div.entry-content h4, div.entry-content h5, div.entry-content h6, .sewl-section-heading .sewl-heading, .sewell-sidebar .sewl-widget h4.widget-title, .blog-title',
            'font'            => array(
              'family'        => 'Oswald',
              'variant'       => 'regular',
            ),
          ),
        ),
      ),
      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'sewell'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'sewell'),
        'class'               => 'chosen',
        'options'             => array(
          '100'   => 'Thin 100',
          '100i'  => 'Thin 100 Italic',
          '200'   => 'Extra Light 200',
          '200i'  => 'Extra Light 200 Italic',
          '300'   => 'Light 300',
          '300i'  => 'Light 300 Italic',
          '400'   => 'Regular 400',
          '400i'  => 'Regular 400 Italic',
          '500'   => 'Medium 500',
          '500i'  => 'Medium 500 Italic',
          '600'   => 'Semi Bold 600',
          '600i'  => 'Semi Bold 600 Italic',
          '700'   => 'Bold 700',
          '700i'  => 'Bold 700 Italic',
          '800'   => 'Extra Bold 800',
          '800i'  => 'Extra Bold 800 Italic',
          '900'   => 'Black 900',
          '900i'  => 'Black 900 Italic',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Font Weight',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '400' ),
      ),
      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => 'Upload Custom Fonts',
        'button_title'       => 'Add New Custom Font',
        'accordion_title'    => 'Adding New Font',
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => 'Font-Family Name',
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),
          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => __('Upload .ttf <small><i>(optional)</i></small>', 'sewell'),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'sewell'),
              'button_title' => __('Upload <i>.ttf</i>', 'sewell'),
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => __('Upload .eot <small><i>(optional)</i></small>', 'sewell'),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'sewell'),
              'button_title' => __('Upload <i>.eot</i>', 'sewell'),
            ),
          ),

          array(
            'id'             => 'svg',
            'type'           => 'upload',
            'title'          => __('Upload .svg <small><i>(optional)</i></small>', 'sewell'),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'sewell'),
              'button_title' => __('Upload <i>.svg</i>', 'sewell'),
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => __('Upload .otf <small><i>(optional)</i></small>', 'sewell'),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'sewell'),
              'button_title' => 'Upload <i>.otf</i>',
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => __('Upload .woff <small><i>(optional)</i></small>', 'sewell'),
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => esc_html__('Use this Font-Format', 'sewell'),
              'button_title' => __('Upload <i>.woff</i>', 'sewell'),
            ),
          ),
          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => __('Extra CSS Style <small><i>(optional)</i></small>', 'sewell'),
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field
    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'sewell'),
    'icon'   => 'fa fa-files-o'
  );

  // ------------------------------
  // Portfolio Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'portfolio_section',
    'title'    => esc_html__('Portfolio', 'sewell'),
    'icon'     => 'fa fa-briefcase',
    'fields' => array(

      // portfolio name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'sewell')
      ),
      array(
        'id'      => 'theme_portfolio_name',
        'type'    => 'text',
        'title'   => esc_html__('Portfolio Name', 'sewell'),
        'attributes'     => array(
          'placeholder'  => 'Portfolio'
        ),
      ),
      array(
        'id'      => 'theme_portfolio_slug',
        'type'    => 'text',
        'title'   => esc_html__('Portfolio Slug', 'sewell'),
        'attributes'     => array(
          'placeholder'  => 'portfolio-item'
        ),
      ),
      array(
        'id'      => 'theme_portfolio_cat_slug',
        'type'    => 'text',
        'title'   => esc_html__('Portfolio Category Slug', 'sewell'),
        'attributes'     => array(
          'placeholder'  => 'portfolio-category'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => __('<strong>Important</strong>: Please do not set portfolio slug and page slug as same. It\'ll not work.', 'sewell')
      ),
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Single Portfolio', 'sewell')
      ),
      array(
        'id'      => 'portfolio_single_pagination',
        'type'    => 'switcher',
        'title'   => esc_html__('Next & Prev Navigation', 'sewell'),
        'label'   => esc_html__('If you don\'t want next and previous navigation in portfolio single pages, please turn this OFF.', 'sewell'),
        'default'   => true,
      ),
      array(
        'id'      => 'portfolio_home_url',
        'type'    => 'text',
        'title'   => esc_html__('Portfolio URL', 'sewell'),
         'attributes' => array(
            'placeholder'     => esc_html__('http://yourdomain.com/portfolio', 'sewell'),
        ),
      ),
     array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Portfolio Archive', 'sewell')
      ),
      array(
        'id'      => 'archive_style',
        'type'    => 'select',
        'title'   => esc_html__('Portfolio Taxonomy Style', 'sewell'),
        'options'        => array(
              'grid' => esc_html__('Grid', 'sewell'),
              'masonry' => esc_html__('Masonry', 'sewell'),
            ),
      ),
      array(
        'id'      => 'portfolio_column',
        'type'    => 'select',
        'title'   => esc_html__('Portfolio Taxonomy Column', 'sewell'),
        'options'        => array(
              'col-item-5' => esc_html__('Five Columns', 'sewell'),
              'col-item-4' => esc_html__('Four Columns', 'sewell'),
              'col-item-3' => esc_html__('Three Columns', 'sewell'),
              'col-item-2' => esc_html__('Two Columns', 'sewell'),
            ),
      ),
      array(
        'id'      => 'portfolio_pagination',
        'type'    => 'select',
        'title'   => esc_html__('Portfolio Taxonomy Pagination', 'sewell'),
        'options'        => array(
              'loadmore_btn' => esc_html__('Ajax Button', 'sewell'),
              'infinitescroll' => esc_html__('Ajax Infinite Scroll', 'sewell'),
              'navigation' => esc_html__('Navigation', 'sewell'),
            ),
      ),
      // Portfolio Listing
    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'sewell'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'sewell'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Layout', 'sewell')
          ),
          array(
            'id'             => 'blog_style',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style', 'sewell'),
            'options'        => array(
              'classic' => esc_html__('Classic', 'sewell'),
              'splitted' => esc_html__('Splitted', 'sewell'),
            ),
          ),
          array(
            'id'             => 'blog_splite_bg',
            'type'           => 'image',
            'title'          => esc_html__('Blog Title Background', 'sewell'),
            'dependency'   => array( 'blog_style', '==', 'splitted' ),
          ),
          array(
            'id'             => 'archive_splite_bg',
            'type'           => 'image',
            'title'          => esc_html__('Archive Title Background', 'sewell'),
            'dependency'   => array( 'blog_style', '==', 'splitted' ),
          ),
          array(
            'id'             => 'blog_splite_title',
            'type'           => 'text',
            'title'          => esc_html__('Blog Page Title', 'sewell'),
            'dependency'     => array( 'blog_style', '==', 'splitted' ),
            'placeholder'    => 'Blog',
          ),
          array(
            'id'             => 'blog_splite_sub_title',
            'type'           => 'text',
            'title'          => esc_html__('Blog Page Sub Title', 'sewell'),
            'dependency'     => array( 'blog_style', '==', 'splitted' ),
            'placeholder'    => 'Blog Sub Title',
          ),
          // Layout
          // Global Options
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'sewell'),
            'options'        => array(
              'sidebar-hide' => esc_html__('Hide', 'sewell'),
              'sidebar-right' => esc_html__('Right', 'sewell'),
              'sidebar-left' => esc_html__('Left', 'sewell'),
            ),
            'dependency'     => array( 'blog_style', '==', 'classic' ),
            'default_option' => 'Select sidebar position',
            'default' => 'sidebar-right',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'sewell'),
            'info'          => esc_html__('Default option : Hide', 'sewell'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'sewell'),
            'options'        => sewell_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'sewell'),
            'default'        => 'sidebar-1',
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'sewell'),
          ),
          array(
            'id'             => 'blog_pagination_type',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style', 'sewell'),
            'options'        => array(
              'navigation' => esc_html__('Navigation', 'sewell'),
              'ajax_load_button' => esc_html__('Ajax Load Button', 'sewell'),
              'infinite_scroll' => esc_html__('Infinite Scroll', 'sewell'),
            ),
            'default_option' => 'Navigation',
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Global Options', 'sewell')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'sewell'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'sewell'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'sewell'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'sewell'),
            'default' => '33',
          ),
          array(
            'id'      => 'blog_post_format_support',
            'type'    => 'checkbox',
            'title'   => esc_html__('Post Formats', 'sewell'),
            'class'      => 'vertical',
            'options'    => array(
              'image'   => esc_html__('Image', 'sewell'),
              'gallery'   => esc_html__('Gallery', 'sewell'),
              'video'   => esc_html__('Video', 'sewell'),
              'audio'   => esc_html__('Audio', 'sewell'),
              'quote'   => esc_html__('Quote', 'sewell'),
              'link'   => esc_html__('Link', 'sewell'),            ),
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'sewell'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'sewell'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'sewell'),
              'date'    => esc_html__('Date', 'sewell'),
              'author'     => esc_html__('Author', 'sewell'),
              'comments'      => esc_html__('Comments', 'sewell'),
            ), // 'default' => '30',
          ), // End fields
        )
      ),
      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'sewell'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(
          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Enable / Disable', 'sewell')
          ),
          array(
            'id'    => 'single_featured_image',
            'type'  => 'switcher',
            'title' => esc_html__('Featured Image', 'sewell'),
            'info' => esc_html__('If need to hide featured image from single blog post page, please turn this OFF.', 'sewell'),
            'default' => true,
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Sidebar', 'sewell')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'sewell'),
            'options'        => array(
              'hide-sidebar' => esc_html__('Hide', 'sewell'),
              'right-sidebar' => esc_html__('Right', 'sewell'),
              'left-sidebar' => esc_html__('Left', 'sewell'),
            ),
            'default_option' => 'Select sidebar position',
            'default'       => 'sidebar-right',
            'info'          => esc_html__('Default option : Hide', 'sewell'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'sewell'),
            'options'        => sewell_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'sewell'),
            'default'        => 'sidebar-1',
            'dependency'     => array('single_sidebar_position', '!=', 'hide-sidebar'),
            'info'          => esc_html__('Default option : Main Widget Area', 'sewell'),
          ),
          array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'sewell'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this OFF.', 'sewell'),
            'default' => true,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'sewell'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'sewell'),
            'default' => true,
          ),
          array(
            'id'    => 'single_comment_form',
            'type'  => 'switcher',
            'title' => esc_html__('Comment Area/Form', 'sewell'),
            'info' => esc_html__('If need to hide comment area and that form on single blog page, please turn this OFF.', 'sewell'),
            'default' => true,
          ),
          // End fields
        )
      ),

    ),
  );

  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'sewell'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // PASSOWRD PROOFING
      array(
        'name'     => 'password_proofing_form',
        'title'    => esc_html__('Password Proofing', 'sewell'),
        'icon'     => 'fa fa-unlock',
        'fields'   => array(
          array(
            'id'    => 'password_title',
            'type'  => 'text',
            'title' => esc_html__('Title', 'sewell'),
          ),
          array(
            'id'    => 'password_button_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'sewell'),
          ),
          array(
            'id'    => 'password_proof_bg',
            'type'  => 'image',
            'title' => esc_html__('Background', 'sewell'),
            'add_title' => esc_html__('Add Background Image', 'sewell'),
          ),

        ) // end: fields
      ), // end: PASSOWRD PROOFING

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'sewell'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'sewell'),
            'info'  => esc_html__('Enter 404 page heading.', 'sewell'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'sewell'),
            'info'  => esc_html__('Enter 404 page content.', 'sewell'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_page_bg',
            'type'  => 'image',
            'title' => esc_html__('404 Page Background', 'sewell'),
            'info'  => esc_html__('Choose 404 page background styles.', 'sewell'),
            'add_title' => esc_html__('Add 404 Image', 'sewell'),
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'sewell'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'sewell'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section

      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'sewell'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => __('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : <strong>Maintenance Mode Page</strong>', 'sewell')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'sewell'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'sewell'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'sewell'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_bg',
            'type'           => 'background',
            'title'          => esc_html__('Page Background', 'sewell'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'sewell'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'sewell'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(
      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'sewell'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'sewell'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'sewell'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'sewell'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'sewell'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'sewell'),
            'accordion_title' => esc_html__('New Sidebar', 'sewell'),
          ),
          // end fields

        )
      ),
      // custom sidebar section

      // Custom CSS/JS
      array(
        'name'        => 'custom_css_js_section',
        'title'       => esc_html__('Custom Codes', 'sewell'),
        'icon'        => 'fa fa-code',

        // begin: fields
        'fields'      => array(

          // Start Custom CSS/JS
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Custom CSS', 'sewell')
          ),
          array(
            'id'             => 'theme_custom_css',
            'type'           => 'textarea',
            'attributes' => array(
              'rows'     => 10,
              'placeholder'     => esc_html__('Enter your CSS code here...', 'sewell'),
            ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Custom JS', 'sewell')
          ),
          array(
            'id'             => 'theme_custom_js',
            'type'           => 'textarea',
            'attributes' => array(
              'rows'     => 10,
              'placeholder'     => esc_html__('Enter your JS code here...', 'sewell'),
            ),
          ),
          // End Custom CSS/JS

        ) // end: fields
      ),

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'sewell'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(

          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Common Texts', 'sewell')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'sewell'),
          ),
          array(
            'id'          => 'share_text',
            'type'        => 'text',
            'title'       => esc_html__('Share Text', 'sewell'),
          ),
          array(
            'id'          => 'share_on_text',
            'type'        => 'text',
            'title'       => esc_html__('Share On Tooltip Text', 'sewell'),
          ),
          array(
            'id'          => 'close_text',
            'type'        => 'text',
            'title'       => esc_html__('Close', 'sewell'),
          ),
          array(
            'id'          => 'p_info_text',
            'type'        => 'text',
            'title'       => esc_html__('Project Info', 'sewell'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'sewell'),
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Pagination', 'sewell')
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'sewell'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'sewell'),
          ),
          // End Translation

        ) // end: fields
      ),

    ),
  );

  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => esc_html__('Backup', 'sewell'),
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'sewell'),
      ),

      array(
        'type'    => 'backup',
      ),

    )
  );

  return $options;

}
add_filter( 'cs_framework_options', 'sewell_vt_options' );
